---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2010-07-30;122
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20100730&codiceRedaz=010G0146&dataVigenza=20251104
dataGU: 20100730
codiceRedaz: 010G0146
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 31 maggio 2010, n. 78, recante misure urgenti in materia di stabilizzazione finanziaria e di competitivita' economica. (10G0146)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 31 maggio 2010, n. 78, recante misure urgenti in materia di stabilizzazione finanziaria e di competitivita' economica, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base degli articoli 5, comma 10, e 12, comma 12, del decreto-legge 31 maggio 2010, n. 78, nonche' del decreto-legge 23 giugno 2010, n. 94.

3. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

